pari_galdata: PARI data package needed to compute Galois groups in degrees 8 through 11
=======================================================================================

Description
-----------

PARI package "galdata": Needed by polgalois to compute Galois group in
degrees 8 through 11.

License
-------

GPL version 2+


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/

